/* eslint-disable import/no-extraneous-dependencies */

const path = require('path');

const FriendlyErrorsWebpackPlugin = require('friendly-errors-webpack-plugin');
const WebpackNotifierPlugin = require('webpack-notifier');

const cssNameBuilder = require('./../shared/cssUniqueNameBuilder');

module.exports = () => {
  const prod = process.env.NODE_ENV === 'production';

  const externals = prod
    ? { react: 'umd react', 'react-dom': 'umd react-dom' }
    : {};

  const resolve = prod
    ? {
      extensions: ['.js', '.jsx', '.scss'],
      alias: {
        react: path.resolve('./node_modules/react'),
        'react-dom': path.resolve('./node_modules/react-dom')
      }
    }
    : { extensions: ['.js', '.jsx', '.scss'] };

  return {
    devServer: {
      disableHostCheck: true,
      host: '0.0.0.0'
    },

    entry: './src/index.js',

    module: {
      rules: [
        {
          test: /\.jsx?$/,
          loader: 'babel-loader',
          include: [path.resolve(__dirname, 'src'), path.resolve(__dirname, 'sandbox')]
        },
        {
          test: /\.s?[ca]ss$/,
          exclude: /node_modules/,
          use: [
            { loader: 'style-loader' },
            { loader: 'css-loader', options: { modules: true, importLoaders: 1, localIdentName: cssNameBuilder() } },
            { loader: 'postcss-loader', options: { config: { path: path.resolve(__dirname, 'postcss.config.js') } } }
          ]
        }
      ]
    },

    output: {
      path: path.resolve(''),
      filename: 'index.js',
      libraryTarget: 'umd'
    },

    plugins: [
      new FriendlyErrorsWebpackPlugin(),
      new WebpackNotifierPlugin({ alwaysNotify: false })
    ],

    externals,

    resolve
  };
};
